@@ -18,17 +18,15 @@
 #include <dirent.h>
 #include <string.h>
 
-#include <libgnome/libgnome.h>
-#include <libgnome/gnome-desktop-item.h>
-#include <libgnomeui/libgnomeui.h>
+#include <glib/gi18n.h>
 #include <libgnomeui/gnome-ditem-edit.h>
+#include <libgnomeui/gnome-url.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <gdk/gdkx.h>
 
 #include "launcher.h"
 
 #include "button-widget.h"
-#include "menu-fentry.h"
 #include "menu.h"
 #include "panel-util.h"
 #include "panel-config-global.h"
@@ -41,8 +39,6 @@
 #include "panel-multiscreen.h"
 #include "panel-lockdown.h"
 
-#include "quick-desktop-reader.h"
-
 #undef LAUNCHER_DEBUG
 
 static void properties_apply (Launcher *launcher);
@@ -57,9 +53,9 @@ launcher_get_screen (Launcher *launcher)
 {
 	PanelWidget *panel_widget;
 
-	g_return_val_if_fail (launcher != NULL, 0);
-	g_return_val_if_fail (launcher->info != NULL, 0);
-	g_return_val_if_fail (launcher->info->widget != NULL, 0);
+	g_return_val_if_fail (launcher != NULL, NULL);
+	g_return_val_if_fail (launcher->info != NULL, NULL);
+	g_return_val_if_fail (launcher->info->widget != NULL, NULL);
 
 	panel_widget = PANEL_WIDGET (launcher->info->widget->parent);
 
@@ -384,7 +380,7 @@ drag_drop_cb (GtkWidget	        *widget,
 	      guint              time,
 	      Launcher          *launcher)
 {
-	static GdkAtom text_uri_list = 0;
+	static GdkAtom text_uri_list = NULL;
 
 	if ( ! is_this_drop_ok (widget, context))
 		return FALSE;
@@ -839,7 +835,6 @@ panel_launcher_ensure_hoarded (Launcher   *launcher,
 			       const char *id)
 {
 	GConfClient *client;
-	const char  *profile;
 	const char  *key;
 	const char  *new_location = NULL;
 
@@ -847,8 +842,7 @@ panel_launcher_ensure_hoarded (Launcher   *launcher,
 		return; /* already hoarded */
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "launcher_location");
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "launcher_location");
 	if ( ! gconf_client_key_is_writable (client, key, NULL)) {
 		/* can't hoard */
 		launcher->non_writable = TRUE;
@@ -882,7 +876,6 @@ launcher_load_from_gconf (PanelWidget *panel_widget,
 {
 	GConfClient *client;
 	Launcher    *launcher;
-	const char  *profile;
 	const char  *key;
 	char        *launcher_location;
 
@@ -890,9 +883,8 @@ launcher_load_from_gconf (PanelWidget *panel_widget,
 	g_return_if_fail (id != NULL);
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "launcher_location");
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "launcher_location");
 	launcher_location = gconf_client_get_string (client, key, NULL);
 
 	if (!launcher_location) {
@@ -1105,18 +1097,16 @@ panel_launcher_create_with_id (const char    *toplevel_id,
 			       const char    *location)
 {
 	GConfClient *client;
-	const char  *profile;
 	const char  *key;
 	char        *id;
 
 	g_return_if_fail (location != NULL);
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 
 	id = panel_profile_prepare_object_with_id (PANEL_OBJECT_LAUNCHER, toplevel_id, position, FALSE);
 
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "launcher_location");
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "launcher_location");
 	gconf_client_set_string (client, key, location, NULL);
 
 	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, id);
