@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * panel-applet-frame.c: panel side container for applets
  *
@@ -27,7 +28,6 @@
 
 #include <libbonoboui.h>
 #include <gconf/gconf.h>
-#include <libgnome/libgnome.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
@@ -316,16 +316,13 @@ panel_applet_frame_load_from_gconf (PanelWidget *panel_widget,
 				    int          position,
 				    const char  *id)
 {
-	const char  *profile;
 	const char  *key;
 	char        *applet_iid;
 
 	g_return_if_fail (panel_widget != NULL);
 	g_return_if_fail (id != NULL);
 
-	profile = panel_profile_get_name ();
-
-	key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, id, "bonobo_iid");
+	key = panel_gconf_full_key (PANEL_GCONF_APPLETS, id, "bonobo_iid");
 	applet_iid = gconf_client_get_string (panel_gconf_get_client (), key, NULL);
 
 	panel_applet_frame_load (applet_iid, panel_widget, locked, position, TRUE, id);
@@ -339,18 +336,16 @@ panel_applet_frame_create (PanelToplevel *toplevel,
 			   const char    *iid)
 {
 	GConfClient *client;
-	const char  *profile;
 	const char  *key;
 	char        *id;
 
 	g_return_if_fail (iid != NULL);
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 
 	id = panel_profile_prepare_object (PANEL_OBJECT_BONOBO, toplevel, position, FALSE);
 
-	key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, id, "bonobo_iid");
+	key = panel_gconf_full_key (PANEL_GCONF_APPLETS, id, "bonobo_iid");
 	gconf_client_set_string (client, key, iid, NULL);
 
 	panel_profile_add_to_list (PANEL_GCONF_APPLETS, id);
@@ -830,18 +825,19 @@ panel_applet_frame_get_name (char *iid)
 
 	list = bonobo_activation_query (query, NULL, NULL);
 	if (list && list->_length > 0 && list->_buffer) {
-		Bonobo_ServerInfo *info = &list->_buffer [0];
-		const GList       *langs_glist;
-		GSList            *langs_gslist;
+		Bonobo_ServerInfo  *info = &list->_buffer [0];
+		const char * const *langs;
+		GSList             *langs_gslist;
+		int                 i;
+
+		langs = g_get_language_names ();
 
-		/* Evil evil evil evil, we need to convert to
-		 * a GSList from a GList */
-		langs_glist = gnome_i18n_get_language_list ("LC_MESSAGES");
 		langs_gslist = NULL;
-		while (langs_glist) {
-			langs_gslist = g_slist_append (langs_gslist, langs_glist->data);
-			langs_glist = langs_glist->next;
-		}
+		for (i = 0; langs[i]; i++)
+			langs_gslist = g_slist_prepend (langs_gslist,
+							(char *) langs[i]);
+
+		langs_gslist = g_slist_reverse (langs_gslist);
 
 		retval = g_strdup (bonobo_server_info_prop_lookup (
 						info, "name", langs_gslist));
@@ -862,9 +858,7 @@ panel_applet_frame_cnx_broken (ORBitConnection  *cnx,
 	GtkWidget *dialog;
 	GdkScreen *screen;
 	char      *applet_name = NULL;
-	char      *applet_txt;
 	char      *dialog_txt;
-	gboolean   locked_down;
 
 	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
 
@@ -873,32 +867,26 @@ panel_applet_frame_cnx_broken (ORBitConnection  *cnx,
 	if (frame->priv->iid)
 		applet_name = panel_applet_frame_get_name (frame->priv->iid);
 
-	locked_down = panel_lockdown_get_locked_down ();
+	if (applet_name)
+		dialog_txt = g_strdup_printf (_("\"%s\" has quit unexpectedly"), applet_name);
+	else
+		dialog_txt = g_strdup (_("Panel object has quit unexpectedly"));
 
-	applet_txt = g_strdup_printf (
-			_("The \"%s\" applet appears to have died "
-			  "unexpectedly.\n\n"
-			  "Do you want to reload this applet?"),
-			applet_name ? applet_name : "");
-	if (!locked_down) {
-		dialog_txt = g_strconcat(applet_txt,
-				_("\n\n"
-				  "(If you choose not to reload it at this time"
-				  " you can always add it by right clicking on "
-				  "the panel and clicking on the "
-				  "\"Add to Panel\" submenu)"),
+	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+					 dialog_txt, applet_name ? applet_name : NULL);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  _("If you reload a panel object, it will automatically "
+						    "be added back to the panel."));
+
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+				_("_Don't Reload"), GTK_RESPONSE_NO,
+				_("_Reload"), GTK_RESPONSE_YES,
 				NULL);
-		g_free (applet_txt);
-	} else {
-		dialog_txt = applet_txt;
-	}
 
-	dialog = gtk_message_dialog_new (
-				NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_QUESTION,
-				GTK_BUTTONS_YES_NO,
-				dialog_txt);
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
 
 	g_signal_connect (dialog, "response",
@@ -1177,9 +1165,9 @@ panel_applet_frame_construct_moniker (PanelAppletFrame *frame,
 	locked_down = panel_lockdown_get_locked_down ();
 
 	retval = g_strdup_printf (
-			"%s!prefs_key=/apps/panel/profiles/%s/applets/%s/prefs;"
+			"%s!prefs_key=/apps/panel/applets/%s/prefs;"
 			"background=%s;orient=%s;size=%s;locked_down=%s",
-			iid, panel_profile_get_name (), id, bg_str,
+			iid, id, bg_str,
 			panel_applet_frame_get_orient_string (frame, panel),
 			panel_applet_frame_get_size_string (frame, panel),
 			locked_down ? "true" : "false");
